diff --git a/substrate/README.adoc b/substrate/README.adoc
index 42d42af822..0b0670a8c0 100644
--- a/substrate/README.adoc
+++ b/substrate/README.adoc
@@ -1,5 +1,5 @@
= Substrate
-:Author: Polkadot developers
+:Author: Substrate developers
:Revision: 0.2.0
:toc:
:sectnums:
diff --git a/substrate/core/cli/README.adoc b/substrate/core/cli/README.adoc
index 2b9b74362d..f847930dab 100644
--- a/substrate/core/cli/README.adoc
+++ b/substrate/core/cli/README.adoc
@@ -8,6 +8,6 @@ include::Cargo.toml[lines=2..5]
----
.Description
-Polkadot CLI library
+Substrate CLI library
include::doc/shell-completion.adoc[]
diff --git a/substrate/core/cli/src/cli.yml b/substrate/core/cli/src/cli.yml
index b237fa4087..6cc9c17393 100644
--- a/substrate/core/cli/src/cli.yml
+++ b/substrate/core/cli/src/cli.yml
@@ -110,11 +110,11 @@ args:
- telemetry:
short: t
long: telemetry
- help: Should connect to the Polkadot telemetry server (telemetry is off by default on local chains)
+ help: Should connect to the Substrate telemetry server (telemetry is off by default on local chains)
takes_value: false
- no-telemetry:
long: no-telemetry
- help: Should not connect to the Polkadot telemetry server (telemetry is on by default on global chains)
+ help: Should not connect to the Substrate telemetry server (telemetry is on by default on global chains)
takes_value: false
- telemetry-url:
long: telemetry-url
diff --git a/substrate/core/cli/src/lib.rs b/substrate/core/cli/src/lib.rs
index d720e45ae9..52cca1dbab 100644
--- a/substrate/core/cli/src/lib.rs
+++ b/substrate/core/cli/src/lib.rs
@@ -493,7 +493,7 @@ fn default_base_path() -> PathBuf {
use app_dirs::{AppInfo, AppDataType};
let app_info = AppInfo {
- name: "Polkadot",
+ name: "Substrate",
author: "Parity Technologies",
};
diff --git a/substrate/core/client/src/backend.rs b/substrate/core/client/src/backend.rs
index 4213453542..4a7f9ecc95 100644
--- a/substrate/core/client/src/backend.rs
+++ b/substrate/core/client/src/backend.rs
@@ -14,7 +14,7 @@
// You should have received a copy of the GNU General Public License
// along with Substrate. If not, see .
-//! Polkadot Client data backend
+//! Substrate Client data backend
use error;
use primitives::AuthorityId;
diff --git a/substrate/core/client/src/blockchain.rs b/substrate/core/client/src/blockchain.rs
index d8e4b8f52c..e4534213d6 100644
--- a/substrate/core/client/src/blockchain.rs
+++ b/substrate/core/client/src/blockchain.rs
@@ -14,7 +14,7 @@
// You should have received a copy of the GNU General Public License
// along with Substrate. If not, see .
-//! Polkadot blockchain trait
+//! Substrate blockchain trait
use primitives::AuthorityId;
use runtime_primitives::traits::{Block as BlockT, Header as HeaderT, NumberFor};
diff --git a/substrate/core/client/src/error.rs b/substrate/core/client/src/error.rs
index 328bc48260..bc73393371 100644
--- a/substrate/core/client/src/error.rs
+++ b/substrate/core/client/src/error.rs
@@ -14,7 +14,7 @@
// You should have received a copy of the GNU General Public License
// along with Substrate. If not, see .
-//! Polkadot client possible errors.
+//! Substrate client possible errors.
use std;
use state_machine;
diff --git a/substrate/core/network/Cargo.toml b/substrate/core/network/Cargo.toml
index 1b1d286e4b..8d602184d9 100644
--- a/substrate/core/network/Cargo.toml
+++ b/substrate/core/network/Cargo.toml
@@ -1,5 +1,5 @@
[package]
-description = "Polkadot network protocol"
+description = "Substrate network protocol"
name = "substrate-network"
version = "0.1.0"
license = "GPL-3.0"
diff --git a/substrate/core/network/src/error.rs b/substrate/core/network/src/error.rs
index 5ad888eb57..48c225e8a0 100644
--- a/substrate/core/network/src/error.rs
+++ b/substrate/core/network/src/error.rs
@@ -14,7 +14,7 @@
// You should have received a copy of the GNU General Public License
// along with Substrate. If not, see .
-//! Polkadot service possible errors.
+//! Substrate service possible errors.
use std::io::Error as IoError;
use network_libp2p::Error as NetworkError;
diff --git a/substrate/core/primitives/src/hasher.rs b/substrate/core/primitives/src/hasher.rs
index f1f9b2e77a..f98a0c7372 100644
--- a/substrate/core/primitives/src/hasher.rs
+++ b/substrate/core/primitives/src/hasher.rs
@@ -14,7 +14,7 @@
// You should have received a copy of the GNU General Public License
// along with Substrate. If not, see .
-//! Polkadot Blake2b Hasher implementation
+//! Substrate Blake2b Hasher implementation
use hash_db::Hasher;
use hash256_std_hasher::Hash256StdHasher;
diff --git a/substrate/core/primitives/src/lib.rs b/substrate/core/primitives/src/lib.rs
index 802298a76b..9b5750e3c5 100644
--- a/substrate/core/primitives/src/lib.rs
+++ b/substrate/core/primitives/src/lib.rs
@@ -15,7 +15,7 @@
// along with Substrate. If not, see .
// tag::description[]
-//! Shareable Polkadot types.
+//! Shareable Substrate types.
// end::description[]
#![warn(missing_docs)]
diff --git a/substrate/core/rpc/src/chain/mod.rs b/substrate/core/rpc/src/chain/mod.rs
index ff9faec81c..07109fee5f 100644
--- a/substrate/core/rpc/src/chain/mod.rs
+++ b/substrate/core/rpc/src/chain/mod.rs
@@ -38,7 +38,7 @@ mod tests;
use self::error::Result;
build_rpc_trait! {
- /// Polkadot blockchain API
+ /// Substrate blockchain API
pub trait ChainApi {
type Metadata;
diff --git a/substrate/core/rpc/src/state/mod.rs b/substrate/core/rpc/src/state/mod.rs
index 31e34be368..7572cc42d0 100644
--- a/substrate/core/rpc/src/state/mod.rs
+++ b/substrate/core/rpc/src/state/mod.rs
@@ -14,7 +14,7 @@
// You should have received a copy of the GNU General Public License
// along with Substrate. If not, see .
-//! Polkadot state API.
+//! Substrate state API.
use std::{
collections::HashMap,
@@ -44,7 +44,7 @@ mod tests;
use self::error::Result;
build_rpc_trait! {
- /// Polkadot state API
+ /// Substrate state API
pub trait StateApi {
type Metadata;
diff --git a/substrate/core/service/src/components.rs b/substrate/core/service/src/components.rs
index f9957e4531..a06f8decfd 100644
--- a/substrate/core/service/src/components.rs
+++ b/substrate/core/service/src/components.rs
@@ -14,7 +14,7 @@
// You should have received a copy of the GNU General Public License
// along with Substrate. If not, see .
-//! Polkadot service components.
+//! Substrate service components.
use std::fmt;
use std::sync::Arc;
diff --git a/substrate/core/sr-std/src/lib.rs b/substrate/core/sr-std/src/lib.rs
index d0fddddd29..77573d73f4 100644
--- a/substrate/core/sr-std/src/lib.rs
+++ b/substrate/core/sr-std/src/lib.rs
@@ -24,8 +24,8 @@
#![cfg_attr(not(feature = "std"), feature(core_intrinsics))]
#![cfg_attr(not(feature = "std"), feature(alloc))]
-#![cfg_attr(feature = "std", doc = "Polkadot runtime standard library as compiled when linked with Rust's standard library.")]
-#![cfg_attr(not(feature = "std"), doc = "Polkadot's runtime standard library as compiled without Rust's standard library.")]
+#![cfg_attr(feature = "std", doc = "Substrate runtime standard library as compiled when linked with Rust's standard library.")]
+#![cfg_attr(not(feature = "std"), doc = "Substrate's runtime standard library as compiled without Rust's standard library.")]
#[macro_export]
macro_rules! map {
diff --git a/substrate/node/consensus/README.adoc b/substrate/node/consensus/README.adoc
index a3ac5f631c..ca2daa9eb2 100644
--- a/substrate/node/consensus/README.adoc
+++ b/substrate/node/consensus/README.adoc
@@ -1,5 +1,5 @@
-= Polkadot Consensus
+= Substrate Consensus
placeholder
//TODO Write content :)
diff --git a/substrate/core/network/src/service.rs b/substrate/core/network/src/service.rs
index c900cae928..10567165ce 100644
--- a/substrate/core/network/src/service.rs
+++ b/substrate/core/network/src/service.rs
@@ -141,7 +141,7 @@ pub struct Params {
pub config: ProtocolConfig,
/// Network layer configuration.
pub network_config: NetworkConfiguration,
/// Polkadot relay chain access point.
pub chain: Arc>,
/// On-demand service reference.
pub on_demand: Option>>,
@@ -151,7 +151,7 @@ pub struct Params {
pub specialization: S,
}
/// Polkadot network service. Handles network IO and manages connectivity.
pub struct Service, H: ExHashT> {
/// Network service
network: NetworkService,
@@ -184,7 +184,7 @@ impl, H: ExHashT> Service {
Err(err) => {
match err.kind() {
ErrorKind::Io(ref e) if e.kind() == io::ErrorKind::AddrInUse =>
- warn!("Network port is already in use, make sure that another instance of Polkadot client is not running or change the port using the --port option."),
+ warn!("Network port is already in use, make sure that another instance of Substrate client is not running or change the port using the --port option."),
_ => warn!("Error starting network: {}", err),
};
return Err(err.into())
@@ -141,7 +141,7 @@ pub struct Params {
/// Network layer configuration.
pub network_config: NetworkConfiguration,
- /// Polkadot relay chain access point.
+ /// Substrate relay chain access point.
pub chain: Arc>,
/// On-demand service reference.
@@ -151,7 +151,7 @@ pub struct Params {
pub specialization: S,
}
-/// Polkadot network service. Handles network IO and manages connectivity.
+/// Substrate network service. Handles network IO and manages connectivity.
pub struct Service, H: ExHashT> {
/// Network service